==> haskell-postgresql-libpq-0.9.4.3-5-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-postgresql-libpq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 postgresql-libpq
version:              0.9.4.3
visibility:           public
id:                   postgresql-libpq-0.9.4.3-4UpE2VczKgl8p7NC0fd3Q8
key:                  postgresql-libpq-0.9.4.3-4UpE2VczKgl8p7NC0fd3Q8
license:              BSD-3-Clause
copyright:
    (c) 2010 Grant Monroe
    (c) 2011 Leon P Smith

maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Grant Monroe, Leon P Smith, Joey Adams
homepage:             https://github.com/haskellari/postgresql-libpq
synopsis:             low-level binding to libpq
description:
    This is a binding to libpq: the C application
    programmer'\''s interface to PostgreSQL. libpq is a
    set of library functions that allow client
    programs to pass queries to the PostgreSQL
    backend server and to receive the results of
    these queries.

category:             Database
abi:                  49d3e75da0092b2993891b1474ac2ae7
exposed:              True
exposed-modules:
    Database.PostgreSQL.LibPQ Database.PostgreSQL.LibPQ.Internal

hidden-modules:       Database.PostgreSQL.LibPQ.Compat
import-dirs:          /usr/lib/ghc-9.0.1/site-local/postgresql-libpq-0.9.4.3
library-dirs:
    /usr/lib/ghc-9.0.1/site-local/postgresql-libpq-0.9.4.3 /usr/lib

dynamic-library-dirs: /usr/lib /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/postgresql-libpq-0.9.4.3
hs-libraries:         HSpostgresql-libpq-0.9.4.3-4UpE2VczKgl8p7NC0fd3Q8
extra-libraries:      pq
include-dirs:         /usr/include
depends:              base-4.15.0.0 bytestring-0.10.12.1 unix-2.7.2.2
haddock-interfaces:
    /usr/share/doc/haskell-postgresql-libpq/html/postgresql-libpq.haddock

haddock-html:         /usr/share/doc/haskell-postgresql-libpq/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-postgresql-libpq-0.9.4.3-6-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-postgresql-libpq.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 postgresql-libpq
version:              0.9.4.3
visibility:           public
id:                   postgresql-libpq-0.9.4.3-IkP6G59sk5XEvvBwPSqWYy
key:                  postgresql-libpq-0.9.4.3-IkP6G59sk5XEvvBwPSqWYy
license:              BSD-3-Clause
copyright:
    (c) 2010 Grant Monroe
    (c) 2011 Leon P Smith

maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Grant Monroe, Leon P Smith, Joey Adams
homepage:             https://github.com/haskellari/postgresql-libpq
synopsis:             low-level binding to libpq
description:
    This is a binding to libpq: the C application
    programmer'\''s interface to PostgreSQL. libpq is a
    set of library functions that allow client
    programs to pass queries to the PostgreSQL
    backend server and to receive the results of
    these queries.

category:             Database
abi:                  65c37696018ad0f6c516776eb834dd28
exposed:              True
exposed-modules:
    Database.PostgreSQL.LibPQ Database.PostgreSQL.LibPQ.Internal

hidden-modules:       Database.PostgreSQL.LibPQ.Compat
import-dirs:          /usr/lib/ghc-9.0.2/site-local/postgresql-libpq-0.9.4.3
library-dirs:
    /usr/lib/ghc-9.0.2/site-local/postgresql-libpq-0.9.4.3 /usr/lib

dynamic-library-dirs: /usr/lib /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/postgresql-libpq-0.9.4.3
hs-libraries:         HSpostgresql-libpq-0.9.4.3-IkP6G59sk5XEvvBwPSqWYy
extra-libraries:      pq
include-dirs:         /usr/include
depends:              base-4.15.1.0 bytestring-0.10.12.1 unix-2.7.2.2
haddock-interfaces:
    /usr/share/doc/haskell-postgresql-libpq/html/postgresql-libpq.haddock

haddock-html:         /usr/share/doc/haskell-postgresql-libpq/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
